pyersinia
=========


![Logo](https://raw.githubusercontent.com/abirtone/STB/master/stb_lib/doc/images/logo.png)

*pyersinia: Herramienta para ataques de capa de enlace*

Code | https://github.com/nottinghamprisateam/pyersinia
---- | ----------------------------------------------
Issues | https://github.com/nottinghamprisateam/pyersinia/issues/
Python version | Python 3 & 2

What's pyersinia
----------------

Framework realizado en python utilizando la libreria scapy para implementar ataques a protocolos de la capa de enlace.

What's new?
-----------

This pyersinia version, add a lot of new features and fixes, like:

Version 1.0.0
+++++++++++++

- First version released

You can read entire list in CHANGELOG file.

Installation
------------

Install pyersinia is so easy:

```
$ python -m pip install pyersinia
```

**Remember that pyersinia only runs in Python 3**.

Quick start
-----------

You can display inline help writing:

```bash

python pyersinia.py -h
```

Advanced options
----------------

There are the advanced options:

- **-v**, **-vv**, **-vvv**: Enable verbose mode.

References
----------

* OMSTD (Open Methodology for Security Tool Developers): http://omstd.readthedocs.org
* STB (Security Tool Builder): https://github.com/abirtone/STB 
